@@ -26,11 +26,7 @@ def get_hyperlink_preview(link_url):
 
     # following code outside with _hlp_cache_lock to release the lock ASAP.
     if is_new:
-        try:
-            hlp_cache.hlp = HLP.HyperLinkPreview(url=link_url)
-        except:
-            del _hlp_cache[link_url]
-            return None
+        hlp_cache.hlp = HLP.HyperLinkPreview(url=link_url)
         hlp_cache.data_get.set()
     else:
         hlp_cache.data_get.wait()
